==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/CustomFeatureGatesFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CustomFeatureGatesFluentImpl<A extends CustomFeatureGatesFluent<A>> extends BaseFluent<A> implements CustomFeatureGatesFluent<A>{
  public CustomFeatureGatesFluentImpl() {
  }
  public CustomFeatureGatesFluentImpl(CustomFeatureGates instance) {
    this.withDisabled(instance.getDisabled()); 
    this.withEnabled(instance.getEnabled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private List<String> disabled = new ArrayList<String>();
  private List<String> enabled = new ArrayList<String>();
  private Map<String,Object> additionalProperties;
  public A addToDisabled(Integer index,String item) {
    if (this.disabled == null) {this.disabled = new ArrayList<String>();}
    this.disabled.add(index, item);
    return (A)this;
  }
  public A setToDisabled(Integer index,String item) {
    if (this.disabled == null) {this.disabled = new ArrayList<String>();}
    this.disabled.set(index, item); return (A)this;
  }
  public A addToDisabled(java.lang.String... items) {
    if (this.disabled == null) {this.disabled = new ArrayList<String>();}
    for (String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A addAllToDisabled(Collection<String> items) {
    if (this.disabled == null) {this.disabled = new ArrayList<String>();}
    for (String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A removeFromDisabled(java.lang.String... items) {
    for (String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public A removeAllFromDisabled(Collection<String> items) {
    for (String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public List<String> getDisabled() {
    return this.disabled;
  }
  public String getDisabled(Integer index) {
    return this.disabled.get(index);
  }
  public String getFirstDisabled() {
    return this.disabled.get(0);
  }
  public String getLastDisabled() {
    return this.disabled.get(disabled.size() - 1);
  }
  public String getMatchingDisabled(Predicate<String> predicate) {
    for (String item: disabled) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingDisabled(Predicate<String> predicate) {
    for (String item: disabled) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDisabled(List<String> disabled) {
    if (disabled != null) {this.disabled = new ArrayList(); for (String item : disabled){this.addToDisabled(item);}} else { this.disabled = null;} return (A) this;
  }
  public A withDisabled(java.lang.String... disabled) {
    if (this.disabled != null) {this.disabled.clear();}
    if (disabled != null) {for (String item :disabled){ this.addToDisabled(item);}} return (A) this;
  }
  public Boolean hasDisabled() {
    return disabled != null && !disabled.isEmpty();
  }
  public A addToEnabled(Integer index,String item) {
    if (this.enabled == null) {this.enabled = new ArrayList<String>();}
    this.enabled.add(index, item);
    return (A)this;
  }
  public A setToEnabled(Integer index,String item) {
    if (this.enabled == null) {this.enabled = new ArrayList<String>();}
    this.enabled.set(index, item); return (A)this;
  }
  public A addToEnabled(java.lang.String... items) {
    if (this.enabled == null) {this.enabled = new ArrayList<String>();}
    for (String item : items) {this.enabled.add(item);} return (A)this;
  }
  public A addAllToEnabled(Collection<String> items) {
    if (this.enabled == null) {this.enabled = new ArrayList<String>();}
    for (String item : items) {this.enabled.add(item);} return (A)this;
  }
  public A removeFromEnabled(java.lang.String... items) {
    for (String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
  }
  public A removeAllFromEnabled(Collection<String> items) {
    for (String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
  }
  public List<String> getEnabled() {
    return this.enabled;
  }
  public String getEnabled(Integer index) {
    return this.enabled.get(index);
  }
  public String getFirstEnabled() {
    return this.enabled.get(0);
  }
  public String getLastEnabled() {
    return this.enabled.get(enabled.size() - 1);
  }
  public String getMatchingEnabled(Predicate<String> predicate) {
    for (String item: enabled) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingEnabled(Predicate<String> predicate) {
    for (String item: enabled) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withEnabled(List<String> enabled) {
    if (enabled != null) {this.enabled = new ArrayList(); for (String item : enabled){this.addToEnabled(item);}} else { this.enabled = null;} return (A) this;
  }
  public A withEnabled(java.lang.String... enabled) {
    if (this.enabled != null) {this.enabled.clear();}
    if (enabled != null) {for (String item :enabled){ this.addToEnabled(item);}} return (A) this;
  }
  public Boolean hasEnabled() {
    return enabled != null && !enabled.isEmpty();
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomFeatureGatesFluentImpl that = (CustomFeatureGatesFluentImpl) o;
    if (disabled != null ? !disabled.equals(that.disabled) :that.disabled != null) return false;
    if (enabled != null ? !enabled.equals(that.enabled) :that.enabled != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disabled,  enabled,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (disabled != null && !disabled.isEmpty()) { sb.append("disabled:"); sb.append(disabled + ","); }
    if (enabled != null && !enabled.isEmpty()) { sb.append("enabled:"); sb.append(enabled + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/CustomFeatureGatesFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CustomFeatureGatesFluentImpl<A extends CustomFeatureGatesFluent<A>> extends BaseFluent<A> implements CustomFeatureGatesFluent<A>{
  public CustomFeatureGatesFluentImpl() {
  }
  public CustomFeatureGatesFluentImpl(CustomFeatureGates instance) {
    if (instance != null) {
      this.withDisabled(instance.getDisabled());
      this.withEnabled(instance.getEnabled());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private List<String> disabled = new ArrayList<String>();
  private List<String> enabled = new ArrayList<String>();
  private Map<String,Object> additionalProperties;
  public A addToDisabled(int index,String item) {
    if (this.disabled == null) {this.disabled = new ArrayList<String>();}
    this.disabled.add(index, item);
    return (A)this;
  }
  public A setToDisabled(int index,String item) {
    if (this.disabled == null) {this.disabled = new ArrayList<String>();}
    this.disabled.set(index, item); return (A)this;
  }
  public A addToDisabled(java.lang.String... items) {
    if (this.disabled == null) {this.disabled = new ArrayList<String>();}
    for (String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A addAllToDisabled(Collection<String> items) {
    if (this.disabled == null) {this.disabled = new ArrayList<String>();}
    for (String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A removeFromDisabled(java.lang.String... items) {
    for (String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public A removeAllFromDisabled(Collection<String> items) {
    for (String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public List<String> getDisabled() {
    return this.disabled;
  }
  public String getDisabled(int index) {
    return this.disabled.get(index);
  }
  public String getFirstDisabled() {
    return this.disabled.get(0);
  }
  public String getLastDisabled() {
    return this.disabled.get(disabled.size() - 1);
  }
  public String getMatchingDisabled(Predicate<String> predicate) {
    for (String item: disabled) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingDisabled(Predicate<String> predicate) {
    for (String item: disabled) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDisabled(List<String> disabled) {
    if (disabled != null) {this.disabled = new ArrayList(); for (String item : disabled){this.addToDisabled(item);}} else { this.disabled = null;} return (A) this;
  }
  public A withDisabled(java.lang.String... disabled) {
    if (this.disabled != null) {this.disabled.clear(); _visitables.remove("disabled"); }
    if (disabled != null) {for (String item :disabled){ this.addToDisabled(item);}} return (A) this;
  }
  public Boolean hasDisabled() {
    return disabled != null && !disabled.isEmpty();
  }
  public A addToEnabled(int index,String item) {
    if (this.enabled == null) {this.enabled = new ArrayList<String>();}
    this.enabled.add(index, item);
    return (A)this;
  }
  public A setToEnabled(int index,String item) {
    if (this.enabled == null) {this.enabled = new ArrayList<String>();}
    this.enabled.set(index, item); return (A)this;
  }
  public A addToEnabled(java.lang.String... items) {
    if (this.enabled == null) {this.enabled = new ArrayList<String>();}
    for (String item : items) {this.enabled.add(item);} return (A)this;
  }
  public A addAllToEnabled(Collection<String> items) {
    if (this.enabled == null) {this.enabled = new ArrayList<String>();}
    for (String item : items) {this.enabled.add(item);} return (A)this;
  }
  public A removeFromEnabled(java.lang.String... items) {
    for (String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
  }
  public A removeAllFromEnabled(Collection<String> items) {
    for (String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
  }
  public List<String> getEnabled() {
    return this.enabled;
  }
  public String getEnabled(int index) {
    return this.enabled.get(index);
  }
  public String getFirstEnabled() {
    return this.enabled.get(0);
  }
  public String getLastEnabled() {
    return this.enabled.get(enabled.size() - 1);
  }
  public String getMatchingEnabled(Predicate<String> predicate) {
    for (String item: enabled) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingEnabled(Predicate<String> predicate) {
    for (String item: enabled) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withEnabled(List<String> enabled) {
    if (enabled != null) {this.enabled = new ArrayList(); for (String item : enabled){this.addToEnabled(item);}} else { this.enabled = null;} return (A) this;
  }
  public A withEnabled(java.lang.String... enabled) {
    if (this.enabled != null) {this.enabled.clear(); _visitables.remove("enabled"); }
    if (enabled != null) {for (String item :enabled){ this.addToEnabled(item);}} return (A) this;
  }
  public Boolean hasEnabled() {
    return enabled != null && !enabled.isEmpty();
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomFeatureGatesFluentImpl that = (CustomFeatureGatesFluentImpl) o;
    if (!java.util.Objects.equals(disabled, that.disabled)) return false;

    if (!java.util.Objects.equals(enabled, that.enabled)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disabled,  enabled,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (disabled != null && !disabled.isEmpty()) { sb.append("disabled:"); sb.append(disabled + ","); }
    if (enabled != null && !enabled.isEmpty()) { sb.append("enabled:"); sb.append(enabled + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
